'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var reactTransitionGroup = require('react-transition-group');
var classNames = _interopDefault(require('classnames'));

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(source, true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(source).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance");
}

var useToast = function useToast() {
  var _useState = React.useState({}),
      _useState2 = _slicedToArray(_useState, 2),
      props = _useState2[0],
      setProps = _useState2[1];

  var showToast = function showToast() {
    var content = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
    var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    setProps(_objectSpread2({
      content: content
    }, options));
  };

  return {
    showToast: showToast,
    props: props
  };
};

function _slicedToArray$1(arr, i) {
  return _arrayWithHoles$1(arr) || _iterableToArrayLimit$1(arr, i) || _nonIterableRest$1();
}

function _arrayWithHoles$1(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit$1(arr, i) {
  if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
    return;
  }

  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _nonIterableRest$1() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance");
}

var useRequestAnimationFrame = function useRequestAnimationFrame(_ref) {
  var _ref$disable = _ref.disable,
      disable = _ref$disable === void 0 ? false : _ref$disable,
      duration = _ref.duration,
      callback = _ref.callback,
      onFinish = _ref.onFinish;

  var _useState = React.useState(!disable),
      _useState2 = _slicedToArray$1(_useState, 2),
      isActive = _useState2[0],
      setIsActive = _useState2[1];

  var startTime = React.useRef(null);
  var requestId = React.useRef(null);

  var start = function start() {
    setIsActive(true);
  };

  var stop = function stop() {
    setIsActive(false);
  };

  var update = React.useCallback(function (timestamp) {
    if (!startTime.current) {
      startTime.current = timestamp;
    }

    var elapsedTime = timestamp - startTime.current;
    callback(elapsedTime);

    if (!duration || elapsedTime < duration) {
      requestId.current = requestAnimationFrame(update);
    } else {
      if (typeof onFinish === 'function') {
        onFinish();
      }

      stop();
    }
  }, [duration, callback]);
  React.useLayoutEffect(function () {
    if (isActive) {
      startTime.current = null;
      requestId.current = requestAnimationFrame(update);
      return function () {
        cancelAnimationFrame(requestId.current);
      };
    }
  }, [isActive, update]);
  return {
    isActive: isActive,
    start: start,
    stop: stop
  };
};

var style = {"container":"src_container_v1cjO"};

var ToastContainer = function ToastContainer(_ref) {
  var height = _ref.height,
      className = _ref.className,
      content = _ref.content,
      _ref$timeout = _ref.timeout;
  _ref$timeout = _ref$timeout === void 0 ? {} : _ref$timeout;
  var _ref$timeout$duration = _ref$timeout.duration,
      duration = _ref$timeout$duration === void 0 ? 500 : _ref$timeout$duration,
      _ref$timeout$appear = _ref$timeout.appear,
      appear = _ref$timeout$appear === void 0 ? 2000 : _ref$timeout$appear,
      _ref$replaceDuration = _ref.replaceDuration,
      replaceDuration = _ref$replaceDuration === void 0 ? 200 : _ref$replaceDuration;

  var _useState = React.useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      enable = _useState2[0],
      setEnable = _useState2[1];

  var timeoutId = React.useRef(null);
  var previousContent = React.useRef(null);
  var previousEl = React.useRef(null);
  var currentEl = React.useRef(null);

  var _useRaf = useRequestAnimationFrame({
    disable: true,
    duration: replaceDuration,
    callback: function callback(elapsedTime) {
      var percentage = elapsedTime / replaceDuration;

      if (previousEl.current) {
        previousEl.current.style.opacity = 1 - percentage;
      }

      if (currentEl.current) {
        currentEl.current.style.top = "".concat((1 - percentage) * height, "px");
      }
    }
  }),
      isActive = _useRaf.isActive,
      replaceToast = _useRaf.start;

  React.useEffect(function () {
    if (content) {
      setEnable(true);

      if (timeoutId.current) {
        clearTimeout(timeoutId.current);
      }

      timeoutId.current = setTimeout(function () {
        setEnable(false);
      }, appear);
    }

    previousContent.current = content;
  }, [content, appear]);
  var hasAnotherToastComming = previousContent.current && previousContent.current !== content;

  if (hasAnotherToastComming && !isActive) {
    replaceToast();
  }

  return React__default.createElement(reactTransitionGroup.Transition, {
    "in": enable,
    timeout: {
      appear: appear,
      enter: duration,
      exit: duration
    }
  }, function (transitionState) {
    return React__default.createElement("div", {
      style: {
        height: "".concat(height, "px"),
        transitionDuration: "".concat(duration, "ms")
      },
      className: classNames(style.container, className, transitionState)
    }, hasAnotherToastComming ? React__default.createElement(React__default.Fragment, null, React__default.createElement("div", {
      ref: previousEl,
      className: 'previous-content'
    }, previousContent.current), React__default.createElement("div", {
      ref: currentEl,
      style: {
        top: height
      },
      className: 'current-content'
    }, content)) : content);
  });
};

exports.ToastContainer = ToastContainer;
exports.useToast = useToast;
